@@ -22,6 +22,9 @@ from shopyo.api.assets import get_static
 from shopyo.api.assets import register_devstatic
 from shopyo.api.debug import is_yo_debug
 from shopyo.api.file import trycopy
+import click
+
+import sqlalchemy
 
 
 base_path = os.path.dirname(os.path.abspath(__file__))
@@ -35,8 +38,16 @@ from init import installed_packages
 
 
 from shopyo_admin import MyAdminIndexView
+from shopyo_admin import DefaultModelView
+from shopyo_settings.models import Settings
+from shopyo_settings.helpers import set_setting as set_value
+from init import db
 
 
+from dotenv import load_dotenv
+
+load_dotenv()
+
 def create_app(config_name="development"):
 
     global_template_variables = {}
@@ -47,16 +58,48 @@ def create_app(config_name="development"):
         instance_relative_config=True,
     )
 
+    
+
     load_plugins(app, global_template_variables, global_configs, config_name)
     load_config_from_obj(app, config_name)
     load_config_from_instance(app, config_name)
     create_config_json()
     load_extensions(app)
+
+    from shopyo_base import ShopyoBase
+    from shopyo_auth import ShopyoAuth
+    from shopyo_appadmin import ShopyoAppAdmin
+    from shopyo_dashboard import ShopyoDashboard
+    from shopyo_page import ShopyoPage
+    from shopyo_i18n import Shopyoi18n
+    from shopyo_settings import ShopyoSettings 
+    from shopyo_theme import ShopyoTheme
+
+    sh_base = ShopyoBase()
+    sh_auth = ShopyoAuth()
+    sh_appadmin = ShopyoAppAdmin()
+    sh_dashboard = ShopyoDashboard()
+    sh_page = ShopyoPage()
+    sh_i18n = Shopyoi18n()
+    sh_settings = ShopyoSettings()
+    sh_theme = ShopyoTheme()
+
+    sh_base.init_app(app)
+    sh_auth.init_app(app)
+    sh_appadmin.init_app(app)
+    sh_dashboard.init_app(app)
+    sh_page.init_app(app)
+    sh_i18n.init_app(app)
+    sh_settings.init_app(app)
+    sh_theme.init_app(app)
+
     setup_flask_admin(app)
     register_devstatic(app, modules_path)
     load_blueprints(app, config_name, global_template_variables, global_configs)
     setup_theme_paths(app)
     inject_global_vars(app, global_template_variables)
+    sync_keyvalue_envvar(app)
+    custom_commands(db, app)
     return app
 
 
@@ -138,7 +181,7 @@ def setup_flask_admin(app):
         template_mode="bootstrap4",
         index_view=MyAdminIndexView(),
     )
-    # admin.add_view(DefaultModelView(Settings, db.session))
+    admin.add_view(DefaultModelView(Settings, db.session))
     admin.add_link(MenuLink(name="Logout", category="", url="/auth/logout?next=/admin"))
 
 
@@ -255,14 +298,65 @@ def setup_theme_paths(app):
 def inject_global_vars(app, global_template_variables):
     @app.context_processor
     def inject_global_vars():
-        APP_NAME = "dwdwefw"
-
+        APP_NAME = os.environ.get('APP_NAME', 'Demo')
+        def get_setting(env_var):
+            return os.environ.get(env_var)
+        
         base_context = {
             "APP_NAME": APP_NAME,
             "len": len,
             "current_user": current_user,
             "get_static": get_static,
+            "get_setting": get_setting,
+            "get_value": get_setting
         }
         base_context.update(global_template_variables)
 
         return base_context
+    
+
+def sync_keyvalue_envvar(app):
+    with app.app_context():
+        try:
+            set_value(
+                'ACTIVE_FRONT_THEME',os.environ.get('ACTIVE_FRONT_THEME', 'editorial')
+            )
+            set_value(
+                'ACTIVE_BACK_THEME',os.environ.get('ACTIVE_BACK_THEME', 'sneat')
+            )
+            set_value(
+                'SITE_TITLE',os.environ.get('SITE_TITLE', 'Site Info')
+            )
+            set_value(
+                'SITE_DESCRIPTION',os.environ.get('SITE_DESCRIPTION', 'Site Description')
+            )
+            set_value(
+                'APP_NAME',os.environ.get('APP_NAME', 'Default App Name')
+            )
+            set_value(
+                'ACTIVE_ICONSET',os.environ.get('ACTIVE_ICONSET', 'boxicons')
+            )
+        except sqlalchemy.exc.OperationalError as e: # on shopyo initialise command
+            if os.environ.get('FLASK_DEBUG', False):
+                print(e)
+
+def custom_commands(db, app):
+    from flask.cli import with_appcontext
+
+    @click.command("shopyo-seed")
+    @with_appcontext
+    def shopyo_upload():
+
+        for ext in app.extensions:
+            if ext.startswith("shopyo_"):
+                try:
+                    e = app.extensions[ext]
+                    e.upload()
+                    db.session.commit()
+                    click.echo("Uploaded for " + ext)
+                except AttributeError as e:
+                    pass
+
+    app.cli.add_command(shopyo_upload)
+
+
